"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.DBConfig = void 0;
const useGlobalDOMEvents_1 = __importDefault(require("./useGlobalDOMEvents"));
const react_router_1 = require("react-router");
const react_1 = require("react");
const react_indexed_db_hook_1 = require("react-indexed-db-hook");
const react_interval_hook_1 = require("react-interval-hook");
exports.DBConfig = {
    name: "TrackMeDB",
    version: 1,
    objectStoresMeta: [
        {
            store: "trackme",
            storeConfig: { keyPath: "id", autoIncrement: true },
            storeSchema: [
                { name: "appName", keypath: "appName", options: { unique: false } },
                { name: "userId", keypath: "userId", options: { unique: false } },
                { name: "activityType", keypath: "activityType", options: { unique: false } },
                { name: "eventKey", keypath: "eventKey", options: { unique: false } },
                { name: "payload", keypath: "payload", options: { unique: false } },
                { name: "timestamp", keypath: "timestamp", options: { unique: false } },
            ],
        },
    ],
};
(0, react_indexed_db_hook_1.initDB)(exports.DBConfig);
function useTrackerIndexedDB(props) {
    const location = (0, react_router_1.useLocation)();
    const { getAll, add, deleteRecord } = (0, react_indexed_db_hook_1.useIndexedDB)("trackme");
    (0, react_interval_hook_1.useInterval)(() => {
        uploadDataToServer();
    }, 10000);
    (0, useGlobalDOMEvents_1.default)({
        event: {
            keyup: (ev) => {
                console.info("keyup", ev.target);
                pushNewActivityUserEvent("keyup", ev.target, { key: ev.key, keyCode: ev.keyCode });
            },
            click: (ev) => {
                console.info("click", ev.target);
                pushNewActivityUserEvent("click", ev.target);
            },
        },
        cleanup: () => {
            uploadDataToServer();
        }
    });
    (0, react_1.useEffect)(() => {
        uploadDataToServer();
    }, []);
    (0, react_1.useEffect)(() => {
        pushNewActivityViewPage('view_page');
    }, []);
    (0, react_1.useEffect)(() => {
        pushNewActivityViewPage('view_page_click');
    }, [location]);
    const pushNewActivityViewPage = (activityType) => {
        const newValue = {
            appName: props.appName,
            userId: props.userId,
            timestamp: new Date().getTime(),
            activityType,
            payload: { location, window_location: window.location },
        };
        console.info(activityType, newValue);
        insertData(newValue);
    };
    const pushNewActivityUserEvent = (eventKey, eventTarget, additionalData) => {
        const newValue = {
            appName: props.appName,
            userId: props.userId,
            timestamp: new Date().getTime(),
            activityType: "user_event",
            eventKey,
            payload: { additionalData },
        };
        if (eventTarget.hasAttributes()) {
            for (const attr of eventTarget.attributes) {
                newValue.payload[attr.name] = attr.value;
                console.info(`${attr.name} -> ${attr.value}`);
            }
            if (eventTarget.value) {
                newValue.payload['value'] = eventTarget.value;
            }
            if (eventTarget.value) {
                newValue.payload["innerHTML"] = eventTarget.innerHTML;
            }
            if (eventTarget.value) {
                newValue.payload["innerText"] = eventTarget.innerText;
            }
        }
        else {
            console.info("No attributes");
        }
        insertData(newValue);
    };
    const insertData = (newData) => {
        newData.payload = JSON.stringify(newData.payload);
        add(Object.assign({}, newData)).then((event) => {
            var _a;
            console.log("ID Generated: ", (_a = event === null || event === void 0 ? void 0 : event.target) === null || _a === void 0 ? void 0 : _a.result);
        }, (error) => {
            console.log(error);
        });
    };
    const uploadDataToServer = () => {
        getAll().then((activitiesFromDB) => {
            if (activitiesFromDB.length > 0) {
                const willSend = activitiesFromDB.map(item => ({
                    activityId: item.id,
                    appName: item.appName,
                    userId: item.userId,
                    timestamp: item.timestamp,
                    activityType: item.activityType,
                    eventKey: item.eventKey,
                    payload: JSON.parse(item.payload),
                }));
                props.processUpload(willSend, (ids) => {
                    for (const id of ids) {
                        deleteRecord(id).then((event) => {
                            console.info("Deleted!", id);
                        });
                    }
                });
            }
        });
    };
    return { isReady: true };
}
exports.default = useTrackerIndexedDB;
