"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.generateFormRules = void 0;
function generateFormRules(formName, rules) {
    const formRules = [];
    if (rules.includes('required')) {
        formRules.push({
            required: true,
            message: `${formName} harus diisi.`,
        });
    }
    if (rules.includes('email')) {
        formRules.push({
            pattern: /^(([^<>()[\]\\.,;:\s@"]+(\.[^<>()[\]\\.,;:\s@"]+)*)|(".+"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\])|(([a-zA-Z\-0-9]+\.)+[a-zA-Z]{2,}))$/,
            message: `format ${formName} harus valid.`,
        });
    }
    if (rules.includes('phoneNumber')) {
        formRules.push({
            pattern: /^[0-9+ -]+$/,
            message: `${formName} hanya diisi angka.`,
        });
    }
    if (rules.includes('letter-and-space')) {
        formRules.push({
            pattern: /^[a-zA-Z ']+$/,
            message: `${formName} hanya diisi huruf.`,
        });
    }
    if (rules.includes('password')) {
        formRules.push({
            pattern: /^(?=.*[A-Za-z])(?=.*\d)(?=.*[@$!%*#?.,+-=/;:"<>&])[A-Za-z\d@$!%*#?.,+-=/;:"<>&]{8,}$/,
            message: `${formName} minimum 8 karakter (huruf, angka and karakter spesial)`,
        });
    }
    if (rules.includes('numeric')) {
        formRules.push({
            pattern: /^[0-9]+$/,
            message: `${formName} hanya diisi angka.`,
        });
    }
    if (rules.includes('nik')) {
        formRules.push({
            pattern: /^[0-9]{16}$/,
            message: `${formName} harus terdiri dari 16 angka.`,
        });
    }
    if (rules.includes('subdomain')) {
        formRules.push({
            pattern: /^[0-9a-zA-Z-]+$/,
            message: `${formName} only contain alphabet, numeric and dash.`
        });
    }
    return formRules;
}
exports.generateFormRules = generateFormRules;
